function [rho, t] = p_fptd(mu, q, Om, phi, sigma, tmax, varargin),

%                                                                      
% First-passage-time density for periodic stimuli                      
%                                                                      
%  [rho, t] = p_fptd(mu, q, Om, phi, sigma, tmax [, OPTIONS])              
%                                                                      
%  Input:         mu  DC input                                         
%                  q  amplitude of AC input			       
%                 Om  stimulus frequency / pi [ in radians ]
%                phi  stimulus phase at t = 0 [ in degrees ]                
%              sigma  rms amplitude of noise			       
%               tmax  time limit for computation		       
%
%  Output:    rho(t)  first-passage-time density                       
%								       
%  Options:   name-value pairs, e.g., ... ,'r', 0.7)
%             r  ###  reset potential  [ default : 0 ]	    	               
%                                                                      
%             N  ###  number of points [ 100 per period, < 50000 ]     
%             n  ###  number of points per section [ number of points ]
%             M  ###  terminate if norm > ### [ 0.9999 ]               
%             m  ###  terminate if norm < ###*curr_pts/tot_pts [ 0.7 ]
%                                                                      
%             When the option -n ### is used, the calculation is split 
%             into sections of ### points.  The calculation is termi-  
%             nated after a section if either the minimum total norm   
%             has been reached (default 0.9999, set with -M ###), or   
%             the norm is less than 0.7 (change with -m ###) of the    
%             fraction of points computed so far (i.e. one is to expect
%             that if the compuation were continued over the total     
%             number of points, only a norm of less than 0.7 would be  
%             obtained.  Since CPU time grows quadratically with number
%             of computed points, sectioning is STRONGLY advised!      
%                                                                      
%  Note:      Negative functions values arising from numerical noise   
%             are set to zero to stabilize the computation.            

% Code see p_fptd.c

% Copyright (C) 2000 Hans Ekkehard Plesser
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
