function [isi, t, sig, scale, t_bord] = isi_dist(trains, range, nobins),

%    [isi, t, sig, scale, t_bord] = isi_dist(trains, range, nobins)
%
%    Inter Spike Interval Distribution from Spike Train
%
%    trains   columns are spike trains (absolute times of spikes, not ISI)
%    range    [min, max] of histogram axis
%    nobins   number of bins
%
%    isi      distribution, normalized
%    t        time axis, bin centers
%    sig      std deviation of bin content
%    scale    scale * isi is spike count
%    t_bord   time axis, bin borders, including end of last bin

%  Copyright (C) 2000 Hans Ekkehard Plesser
%
%  This program is free software; you can redistribute it and/or
%  modify it under the terms of the GNU General Public License
%  as published by the Free Software Foundation; either version 2
%  of the License, or (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program; if not, write to the Free Software
%  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

% get axis
[nospikes, notrains] = size(trains);
t_min = range(1);
t_max = range(2);
dt = (t_max - t_min) / nobins;
t  = t_min + 0.5 * dt + (0:(nobins-1)) * dt;

% get bin numbers
bins = 1 + floor((diff(trains) - t_min) / dt);

% build histogram
isi = zeros(nobins, notrains);
for bin = 1:nobins,
  isi(bin, :) = sum(bins == bin);
end

% number of valid spikes, including those cut off by histogram range
N = repmat(sum(~isnan(bins)), [nobins, 1]);

% normalized histogram
isi   = isi ./ (dt*N);

% return t as column
t = t(:);

if nargout > 2,
  % std dev of bin count, see Scott (1992)
  sig = sqrt(isi .* (1/dt - isi) ./ N);
end

if nargout > 3,
  % histogram scaling factor
  scale = dt * N(1,:);
end

if nargout > 4,
  % bin borders
  t_bord = t_min + (0:nobins) * dt;
end

return



