/**************************************************************************
* Copyright 1995 Thomas Fricke
*
* Permission to use, copy, modify, distribute, and sell
* this software and its documentation for any purpose is
* hereby granted without fee, provided that the above copyright
* notice appear in all copies and that both that copyright notice
* and this permission notice appear in supporting documentation,
* and that the name of Thomas Fricke not be used in advertising or
* publicity pertaining to distribution of the software without
* specific, written prior permission.  Thomas Fricke makes no representations
* about the suitability of this software for any purpose.
* It is provided "as is" without express or implied warranty.
*
* THOMAS FRICKE DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
* INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
* IN NO EVENT SHALL THOMAS FRICKE BE LIABLE FOR ANY SPECIAL, INDIRECT OR
* CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
* LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
* NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
* CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*
* Author:
*        Thomas Fricke
*        Inst. f. Physik
*        Lehrstuhl fuer Stochastische Prozess
*        Humboldt Universitaet zu Berlin
*        Invalidenstr. 110
*        D - 10115 Berlin
*        GERMANY
*
*/

#include <math.h>
#include <stdio.h>
#include "rand55.h"

#define TESTDIST(DISTRIBUTION,name,ex1,ex2) \
                printf("%-14s:",name);fflush(stdout);\
		for(e1=e2=0, i=0 ; i<tn ; i++) {\
			d=(double)DISTRIBUTION;\
			e1+=d;	e2+=d*d;}\
                var=sqrt(ex2/(double)tn);\
		printf("%9lf (%9lf+-%9lf) %9lf ( %9lf ) %s\n",\
		 e1/tn, (double)(ex1), var, e2/tn, (double)(ex2),((abs(e1/tn-ex1)<2*var)?"OK":"WRONG") );

int main(int argc, char **arglist)
{
	double e1, e2, d ,var;
	long tn, i, seed;

#ifdef MAKEDAT	
	seed=init_rand55(9999999L);
#else
	seed=init_rand55(0L);
#endif

	if (argc==2){
	    tn=atol(arglist[1]);
	}
	else{
	    fprintf(stderr,"expecting exactly one argument\n");
	    exit(-1);
	}
	    
	if(tn){
	    printf("Testing each function n=%ld times\n%-14s:%-9s (%-20s) %-9s (%-9s)\n",
		   tn,"function","   <x>", "xpctd+-sqrt(<x^2>/n)", "   <x^2>", "expected");
	    printf("-----------------------------------------------------------------------\n");
	    TESTDIST(drand55(),"drand55()",0.5,0.33333333333333)
		TESTDIST(lrand55(10),"lrand55(10)",4.5,28.5)
		TESTDIST(exp_rand55(),"exp_rand55()",1,2)
		TESTDIST(gauss_rand55(),"gauss_rand55()",0,1)
	}

/* #ifndef MAKEDAT	 */
/* 	init_rand55(seed); */

/* 	if(tn){ */
/* 	    printf("Testing each function n=%ld times\n%-14s:%-9s (%-20s) %-9s (%-9s)\n", */
/* 		   tn,"function","   <x>", "xpctd+-sqrt(<x^2>/n)", "   <x^2>", "expected"); */
/* 	    printf("-----------------------------------------------------------------------\n"); */
/* 	    TESTDIST(drand55(),"drand55()",0.5,0.33333333333333) */
/* 		TESTDIST(lrand55(10),"lrand55(10)",4.5,28.5) */
/* 		TESTDIST(exp_rand55(),"exp_rand55()",1,2) */
/* 		TESTDIST(gauss_rand55(),"gauss_rand55()",0,1) */
/* 	} */
/* #endif */
	return 0;
}
